==> systray-x_0.5.0.orig.tar.gz: systray-x-0.5.0/app/SysTray-X/languages/SysTray-X.nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.ui" line="14"/>
        <source>About SysTray-X</source>
        <translation>Over SysTray-X</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="26"/>
        <source>SysTray-X Companion App by Ximi1970</source>
        <translation>SysTray-X Companion App door Ximi1970</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="40"/>
        <source>Version:</source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="47"/>
        <source>0.0.1</source>
        <translatorcomment>Niet vertalen</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="54"/>
        <source>Build:</source>
        <translation>Build:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="61"/>
        <location filename="../aboutdialog.ui" line="75"/>
        <source>0</source>
        <translatorcomment>Niet vertalen</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="68"/>
        <source>Hash:</source>
        <translation>Hash:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="82"/>
        <source>Branch:</source>
        <translation>Branch:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="89"/>
        <source>master</source>
        <translatorcomment>Niet vertalen</translatorcomment>
        <translation></translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../debugwidget.ui" line="14"/>
        <source>SysTray-X Debug</source>
        <translation>SysTray-X Debug</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="59"/>
        <source>Test 2</source>
        <translation>Test 2</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="69"/>
        <source>Unread mail:</source>
        <translation>Ongelezen berichten:</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="76"/>
        <source>Test 1</source>
        <translation>Test 1</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="83"/>
        <source>0</source>
        <translatorcomment>Niet vertalen</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="90"/>
        <source>Test 3</source>
        <translation>Test 3</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferences.ui" line="14"/>
        <source>SysTray-X Preferences</source>
        <translation>SysTray-X Opties</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="26"/>
        <source>Default icon</source>
        <translation>Standaard pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="32"/>
        <source>Icon</source>
        <translation>Pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="40"/>
        <source>Default Thunderbird</source>
        <translation>Standaard Thunderbird</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="53"/>
        <source>Lookthrough icon</source>
        <translation>Doorzichtig pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="65"/>
        <location filename="../preferences.ui" line="188"/>
        <source>Custom icon</source>
        <translation>Aangepast pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="82"/>
        <location filename="../preferences.ui" line="205"/>
        <source>Choose</source>
        <translation>Kies</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="99"/>
        <source>KDE integration (Hide)</source>
        <translation>KDE integratie (Verbergen)</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="112"/>
        <source>Mail notification icon</source>
        <translation>Berichten notificatie pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="125"/>
        <source>Blank icon</source>
        <translation>Leeg pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="158"/>
        <source>New mail icon</source>
        <translation>Nieuw bericht pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="219"/>
        <source>No icon</source>
        <translation>Geen pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="266"/>
        <source>Windows</source>
        <translation>Vensters</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="323"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="274"/>
        <source>Minimize</source>
        <translation>Minimaliseren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="282"/>
        <source>Default minimize</source>
        <translation>Standaard minimalisatie</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="295"/>
        <source>Minimize to tray, method 1</source>
        <translation>Minimaliseer naar systeemvak, methode 1</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="308"/>
        <source>Minimize to tray, method 2</source>
        <translation>Minimaliseer naar systeemvak, methode 2</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="344"/>
        <source>Default close</source>
        <translation>Standaard sluiting</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="354"/>
        <source>Minimize main, close children</source>
        <translation>Minimaliseer hoofdvenster, sluit kindvensters</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="367"/>
        <source>Minimize all windows</source>
        <translation>Minimaliseer alle vensters</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="387"/>
        <source>Start application minimized</source>
        <translation>Start programma geminimaliseerd</translation>
    </message>
    <message>
        <source>Minimize on close</source>
        <translation type="vanished">Minimaliseren bij sluiten</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="401"/>
        <source>Number properties</source>
        <translation>Nummer opties</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="409"/>
        <source>Display unread message count</source>
        <translation>Aantal ongelezen berichten weergeven</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="421"/>
        <source>Number color</source>
        <translation>Nummer kleur</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="442"/>
        <source>Number size</source>
        <translation>Nummer grootte</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="464"/>
        <source>Count type</source>
        <translation>Type berichttelling</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="472"/>
        <source>Unread</source>
        <translation>Ongelezen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="485"/>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="522"/>
        <source>Display debug window</source>
        <translation>Toon debug venster</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Bewaren</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Annnuleren</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="49"/>
        <location filename="../preferencesdialog.cpp" line="58"/>
        <source>Minimize to tray</source>
        <translation>Minimaliseer naar systeemvak</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="370"/>
        <location filename="../preferencesdialog.cpp" line="394"/>
        <source>Open Image</source>
        <translation>Open afbeelding</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="370"/>
        <location filename="../preferencesdialog.cpp" line="394"/>
        <source>Image Files (*.png *.jpg *.bmp)</source>
        <translation>Afbeeldingsbestanden (*.png *.jpg *.bmp)</translation>
    </message>
</context>
<context>
    <name>SysTrayX</name>
    <message>
        <location filename="../systrayx.cpp" line="192"/>
        <source>&amp;Show/Hide</source>
        <translation>&amp;Tonen/Verbergen</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="196"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Opties</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="200"/>
        <source>&amp;About</source>
        <translation>O&amp;ver</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="204"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="602"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
</TS>

==> systray-x_0.6.1.orig.tar.gz: systray-x-0.6.1/app/SysTray-X/languages/SysTray-X.nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.ui" line="14"/>
        <source>About SysTray-X</source>
        <translation>Over SysTray-X</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="26"/>
        <source>SysTray-X Companion App by Ximi1970</source>
        <translation>SysTray-X Companion App door Ximi1970</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="40"/>
        <source>Version:</source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="47"/>
        <source>0.0.1</source>
        <translatorcomment>Niet vertalen</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="54"/>
        <source>Build:</source>
        <translation>Build:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="61"/>
        <location filename="../aboutdialog.ui" line="75"/>
        <source>0</source>
        <translatorcomment>Niet vertalen</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="68"/>
        <source>Hash:</source>
        <translation>Hash:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="82"/>
        <source>Branch:</source>
        <translation>Branch:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="89"/>
        <source>master</source>
        <translatorcomment>Niet vertalen</translatorcomment>
        <translation></translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../debugwidget.ui" line="14"/>
        <source>SysTray-X Debug</source>
        <translation>SysTray-X Debug</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="59"/>
        <source>Test 2</source>
        <translation>Test 2</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="69"/>
        <source>Unread mail:</source>
        <translation>Ongelezen berichten:</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="76"/>
        <source>Test 1</source>
        <translation>Test 1</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="83"/>
        <source>0</source>
        <translatorcomment>Niet vertalen</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="90"/>
        <source>Test 3</source>
        <translation>Test 3</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferences.ui" line="14"/>
        <source>SysTray-X Preferences</source>
        <translation>SysTray-X Opties</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="26"/>
        <source>Default icon</source>
        <translation>Standaard pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="32"/>
        <source>Icon</source>
        <translation>Pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="40"/>
        <source>Default Thunderbird</source>
        <translation>Standaard Thunderbird</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="53"/>
        <source>Lookthrough icon</source>
        <translation>Doorzichtig pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="65"/>
        <location filename="../preferences.ui" line="201"/>
        <source>Custom icon</source>
        <translation>Aangepast pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="82"/>
        <location filename="../preferences.ui" line="218"/>
        <source>Choose</source>
        <translation>Kies</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="99"/>
        <source>KDE integration (Hide)</source>
        <translation>KDE integratie (Verbergen)</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="112"/>
        <source>Mail notification icon</source>
        <translation>Berichten notificatie pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="138"/>
        <source>Blank icon</source>
        <translation>Leeg pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="171"/>
        <source>New mail icon</source>
        <translation>Nieuw bericht pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="232"/>
        <source>No icon</source>
        <translation>Geen pictogram</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="279"/>
        <source>Windows</source>
        <translation>Vensters</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="336"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="287"/>
        <source>Minimize</source>
        <translation>Minimaliseren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="295"/>
        <source>Default minimize</source>
        <translation>Standaard minimalisatie</translation>
    </message>
    <message>
        <source>Minimize to tray, method 1</source>
        <translation type="vanished">Minimaliseer naar systeemvak, methode 1</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="321"/>
        <source>Minimize to tray, method 2</source>
        <translation>Minimaliseer naar systeemvak, methode 2</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="344"/>
        <source>Default close</source>
        <translation>Standaard sluiting</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="354"/>
        <source>Minimize main, close children</source>
        <translation>Minimaliseer hoofdvenster, sluit kindvensters</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="367"/>
        <source>Minimize all windows</source>
        <translation>Minimaliseer alle vensters</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="387"/>
        <source>Start application minimized</source>
        <translation>Start programma geminimaliseerd</translation>
    </message>
    <message>
        <source>Minimize on close</source>
        <translation type="vanished">Minimaliseren bij sluiten</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="401"/>
        <source>Number properties</source>
        <translation>Nummer opties</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="409"/>
        <source>Display unread message count</source>
        <translation>Aantal ongelezen berichten weergeven</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="421"/>
        <source>Number color</source>
        <translation>Nummer kleur</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="442"/>
        <source>Number size</source>
        <translation>Nummer grootte</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="464"/>
        <source>Count type</source>
        <translation>Type berichttelling</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="472"/>
        <source>Unread</source>
        <translation>Ongelezen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="485"/>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="522"/>
        <source>Display debug window</source>
        <translation>Toon debug venster</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="542"/>
        <source>Save</source>
        <translation>Bewaren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="549"/>
        <source>Cancel</source>
        <translation>Annnuleren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="308"/>
        <location filename="../preferencesdialog.cpp" line="52"/>
        <location filename="../preferencesdialog.cpp" line="63"/>
        <source>Minimize to tray</source>
        <translation>Minimaliseer naar systeemvak</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="391"/>
        <location filename="../preferencesdialog.cpp" line="415"/>
        <source>Open Image</source>
        <translation>Open afbeelding</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="391"/>
        <location filename="../preferencesdialog.cpp" line="415"/>
        <source>Image Files (*.png *.jpg *.bmp)</source>
        <translation>Afbeeldingsbestanden (*.png *.jpg *.bmp)</translation>
    </message>
</context>
<context>
    <name>SysTrayX</name>
    <message>
        <location filename="../systrayx.cpp" line="194"/>
        <source>&amp;Show/Hide</source>
        <translation>&amp;Tonen/Verbergen</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="198"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Opties</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="202"/>
        <source>&amp;About</source>
        <translation>O&amp;ver</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="206"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="604"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
</TS>
